@@ -7,7 +7,7 @@ from . import api
 from .gateway import Requestable, Gateway
 from .interface import LazyLoadable
 from .role import Role
-from .types import MessageTypes, ChannelTypes, SlowModeTypes
+from ._types import MessageTypes, ChannelTypes, SlowModeTypes
 from .user import User
 from .util import unpack_value
 
